==> openttd-1.9.0-beta1-docs.tar.tar: openttd-1.9.0-beta1-docs/html/dc/d9e/screenshot_8h.js <==
var screenshot_8h =
[
    [ "ScreenshotType", "dc/d9e/screenshot_8h.html#ae0e853a66f5365834218088cb2011718", [
      [ "SC_VIEWPORT", "dc/d9e/screenshot_8h.html#ae0e853a66f5365834218088cb2011718a01d5fc8557ffc0ea8dabfe0873eaa958", null ],
      [ "SC_CRASHLOG", "dc/d9e/screenshot_8h.html#ae0e853a66f5365834218088cb2011718a107c16a90cf0e0c4b4652ad929a93b7f", null ],
      [ "SC_ZOOMEDIN", "dc/d9e/screenshot_8h.html#ae0e853a66f5365834218088cb2011718a1d4be56c5cc410851f4aedd163108c97", null ],
      [ "SC_DEFAULTZOOM", "dc/d9e/screenshot_8h.html#ae0e853a66f5365834218088cb2011718adb81f43d2196411a02df0d4391704f97", null ],
      [ "SC_WORLD", "dc/d9e/screenshot_8h.html#ae0e853a66f5365834218088cb2011718a5d8441b73d4378af83142a86ade16ca3", null ],
      [ "SC_HEIGHTMAP", "dc/d9e/screenshot_8h.html#ae0e853a66f5365834218088cb2011718a41af761c922253865f8d5612389c84ab", null ]
    ] ],
    [ "GetCurrentScreenshotExtension", "dc/d9e/screenshot_8h.html#a369c18b870e82e39bec0f43dc51fd633", null ],
    [ "InitializeScreenshotFormats", "dc/d9e/screenshot_8h.html#a51596ede7024c46c2fafd9cc9f90a70d", null ],
    [ "MakeHeightmapScreenshot", "dc/d9e/screenshot_8h.html#a4a5579a4c480e2365ba047f3546d0745", null ],
    [ "MakeScreenshot", "dc/d9e/screenshot_8h.html#a338eadf27c4f225871228b3c77cdcaf3", null ],
    [ "SetupScreenshotViewport", "dc/d9e/screenshot_8h.html#a4bfdf0bdf909da5037c92d412d3de7be", null ],
    [ "_cur_screenshot_format", "dc/d9e/screenshot_8h.html#af56f743102006f5db05ebefd2ea7726f", null ],
    [ "_full_screenshot_name", "dc/d9e/screenshot_8h.html#a8d7564c0744b9f2cd2ee3bcc91723fee", null ],
    [ "_num_screenshot_formats", "dc/d9e/screenshot_8h.html#ace1cb7f515e1199561426a65e203b845", null ],
    [ "_screenshot_format_name", "dc/d9e/screenshot_8h.html#ae0037568563c24f67d57780523d9cafb", null ]
];

==> openttd-1.11.0-beta1-docs.tar.tar: openttd-1.11.0-beta1-docs/html/dc/d9e/screenshot_8h.js <==
var screenshot_8h =
[
    [ "ScreenshotType", "dc/d9e/screenshot_8h.html#ae0e853a66f5365834218088cb2011718", [
      [ "SC_VIEWPORT", "dc/d9e/screenshot_8h.html#ae0e853a66f5365834218088cb2011718a01d5fc8557ffc0ea8dabfe0873eaa958", null ],
      [ "SC_CRASHLOG", "dc/d9e/screenshot_8h.html#ae0e853a66f5365834218088cb2011718a107c16a90cf0e0c4b4652ad929a93b7f", null ],
      [ "SC_ZOOMEDIN", "dc/d9e/screenshot_8h.html#ae0e853a66f5365834218088cb2011718a1d4be56c5cc410851f4aedd163108c97", null ],
      [ "SC_DEFAULTZOOM", "dc/d9e/screenshot_8h.html#ae0e853a66f5365834218088cb2011718adb81f43d2196411a02df0d4391704f97", null ],
      [ "SC_WORLD", "dc/d9e/screenshot_8h.html#ae0e853a66f5365834218088cb2011718a5d8441b73d4378af83142a86ade16ca3", null ],
      [ "SC_HEIGHTMAP", "dc/d9e/screenshot_8h.html#ae0e853a66f5365834218088cb2011718a41af761c922253865f8d5612389c84ab", null ],
      [ "SC_MINIMAP", "dc/d9e/screenshot_8h.html#ae0e853a66f5365834218088cb2011718a7fd11a9fd703940e1a05778b85a1dead", null ]
    ] ],
    [ "GetCurrentScreenshotExtension", "dc/d9e/screenshot_8h.html#a369c18b870e82e39bec0f43dc51fd633", null ],
    [ "InitializeScreenshotFormats", "dc/d9e/screenshot_8h.html#a51596ede7024c46c2fafd9cc9f90a70d", null ],
    [ "MakeHeightmapScreenshot", "dc/d9e/screenshot_8h.html#a4a5579a4c480e2365ba047f3546d0745", null ],
    [ "MakeMinimapWorldScreenshot", "dc/d9e/screenshot_8h.html#a529a280984bff52054b619426226d05d", null ],
    [ "MakeScreenshot", "dc/d9e/screenshot_8h.html#a338eadf27c4f225871228b3c77cdcaf3", null ],
    [ "MakeScreenshotWithConfirm", "dc/d9e/screenshot_8h.html#a25308658cd441024aaff8169032b8cf6", null ],
    [ "SetupScreenshotViewport", "dc/d9e/screenshot_8h.html#a25d1283988b0e9adc571ebea85d23576", null ],
    [ "_cur_screenshot_format", "dc/d9e/screenshot_8h.html#af56f743102006f5db05ebefd2ea7726f", null ],
    [ "_full_screenshot_name", "dc/d9e/screenshot_8h.html#a8d7564c0744b9f2cd2ee3bcc91723fee", null ],
    [ "_num_screenshot_formats", "dc/d9e/screenshot_8h.html#ace1cb7f515e1199561426a65e203b845", null ],
    [ "_screenshot_format_name", "dc/d9e/screenshot_8h.html#ae0037568563c24f67d57780523d9cafb", null ]
];
